==> nextcloud-22.2.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_external/l10n/eo.js <==
OC.L10N.register(
    "files_external",
    {
    "External storage" : "Ekstera konservejo",
    "Personal" : "Persona",
    "System" : "Sistemo",
    "Grant access" : "Doni alirpermeson",
    "Error configuring OAuth1" : "Eraro dum agordo de OAuth1",
    "Please provide a valid app key and secret." : "Bv. doni validan aplikaĵan ŝlosilon kaj sekreton.",
    "Error configuring OAuth2" : "Eraro dum agordo de OAuth2",
    "Generate keys" : "Generi ŝlosilojn",
    "Error generating key pair" : "Eraro dum generado de ŝlosila paro",
    "All users. Type to select user or group." : "Ĉiuj uzantoj. Entajpu por elekti uzanton aŭ grupon.",
    "Compatibility with Mac NFD encoding (slow)" : "Kongrueco kun Makintoŝa „NFD“ signara kodoprezento (malrapide)",
    "Enable encryption" : "Ŝalti ĉifradon",
    "Enable previews" : "Ŝalti antaŭrigardojn",
    "Enable sharing" : "Ŝalti kunhavigadon",
    "Check for changes" : "Serĉi la modifojn",
    "Never" : "Neniam",
    "Once every direct access" : "Unufoje okaze de senpera aliro",
    "Read only" : "Nurlega",
    "Delete" : "Forigi",
    "Admin defined" : "Difinita de administranto",
    "Are you sure you want to delete this external storage?" : "Ĉu vi certas, ke vi volas forigi tiun eksteran konservejon?",
    "Delete storage?" : "Ĉu forigi konservejon?",
    "Saved" : "Konservita",
    "Saving …" : "Konservado...",
    "Save" : "Konservi",
    "Empty response from the server" : "Malplena respondo el la servilo",
    "Couldn't access. Please log out and in again to activate this mount point" : "Aliro ne eblis. Bv. elsaluti kaj re-ensaluti por aktivigi tiun surmetingon",
    "Couldn't get the information from the remote server: {code} {type}" : "Ne eblis havi informojn el la fora servilo: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Ne eblis havi listojn de eksteraj surmetingoj: {type}",
    "There was an error with message: " : "Estis eraro kun la jena mesaĝo:",
    "External mount error" : "Eraro de surmetingo ekstera",
    "external-storage" : "external-storage",
    "Couldn't fetch list of Windows network drive mount points: Empty response from server" : "Ne eblis ricevi liston de surmetingoj el Windows-retdisko: malplena respondo el la servilo",
    "Please enter the credentials for the {mount} mount" : "Bv. entajpi la akreditilojn de la surmetingo {mount}",
    "Username" : "Uzantnomo",
    "Password" : "Pasvorto",
    "Credentials saved" : "Akreditiloj konservitaj",
    "Credentials saving failed" : "Konservo de akreditiloj malsukcesis",
    "Credentials required" : "Akreditiloj bezonataj",
    "Storage with ID \"%d\" not found" : "Konservejo kun identigilo „%d“ ne trovita",
    "Invalid backend or authentication mechanism class" : "Nevalida interna tipo aŭ aŭtentiga klaso",
    "Invalid mount point" : "Nevalida surmetingo",
    "Objectstore forbidden" : "„Objectstore“ malpermesata",
    "Invalid storage backend \"%s\"" : "Nevalida konserveja interna servo „%s“",
    "Not permitted to use backend \"%s\"" : "Ne permesatas uzi internan servon „%s“",
    "Not permitted to use authentication mechanism \"%s\"" : "Ne permesatas uzi aŭtentigan metodon „%s“",
    "Unsatisfied backend parameters" : "Neplenumitaj internservaj parametroj",
    "Unsatisfied authentication mechanism parameters" : "Neplenumitaj aŭtentigmetodaj parametroj",
    "Insufficient data: %s" : "Nesufiĉaj datumoj: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not user editable" : "Konservejo kun identigilo „%d“ ne estas modifebla de uzantoj",
    "Access key" : "Alira ŝlosilo",
    "Secret key" : "Sekreta ŝlosilo",
    "Builtin" : "Interne instalita",
    "None" : "Nenio",
    "OAuth1" : "OAuth1",
    "App key" : "Aplikaĵa ŝlosilo",
    "App secret" : "Aplikaĵosekreto",
    "OAuth2" : "OAuth2",
    "Client ID" : "Klientidentigilo",
    "Client secret" : "Klientosekreto",
    "OpenStack v2" : "OpenStack v2",
    "Tenant name" : "Nomo de la loĝanto (angle „tenant“)",
    "Identity endpoint URL" : "Retadreso de identeca finpunkto (angle „Identity endpoint“)",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Domajno",
    "Rackspace" : "Rackspace",
    "API key" : "API-ŝlosilo",
    "Global credentials" : "Ĝeneralaj akreditiloj",
    "Log-in credentials, save in database" : "Ensalutaj akreditiloj, konservi en datumbazo",
    "Username and password" : "Uzantnomo kaj pasvorto",
    "Log-in credentials, save in session" : "Ensalutaj akreditiloj, konservi en seanco",
    "Global credentials, user entered" : "Ĝeneralaj akreditiloj, tajpitaj de la uzanto",
    "User entered, store in database" : "Entajpita de uzanto, konservi en datumbazo",
    "RSA public key" : "Publika RSA-ŝlosilo",
    "Public key" : "Publika ŝlosilo",
    "RSA private key" : "Privata RSA-ŝlosilo",
    "Private key" : "Privata ŝlosilo",
    "Kerberos ticket" : "Kerberos-bileto (angle „ticket“)",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Ujo (angle „bucket“)",
    "Hostname" : "Gastigonomo",
    "Port" : "Pordo",
    "Region" : "Regiono",
    "Enable SSL" : "Ŝalti SSL-on",
    "Enable Path Style" : "Uzi vojan stilon („path style“ angle)",
    "Legacy (v2) authentication" : "Aŭtentigo per malnova v2",
    "WebDAV" : "WebDAV",
    "URL" : "Retadreso",
    "Remote subfolder" : "Fora subdosierujo",
    "Secure https://" : "Sekura https://",
    "FTP" : "FTP",
    "Host" : "Gastigo",
    "Secure ftps://" : "Sekura ftps://",
    "Local" : "Loka",
    "Location" : "Loko",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Radiko",
    "SFTP with secret key login" : "SFTP kun sekretoŝlosila ensaluto",
    "Share" : "Kunhavigi",
    "Show hidden files" : "Montri kaŝitajn dosierojn",
    "Timeout" : "Eltempiĝo",
    "Username as share" : "Uzantonmo kiel kunhavo",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Servonomo",
    "Request timeout (seconds)" : "Eltempiĝo (sekundoj)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Subteno de cURL en PHP ne estas ebligita aŭ instalita. Surmetado de %s ne eblas. Bv. vidi kun via administranto.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Subteno de FTP en PHP ne estas ebligita aŭ instalita. Surmetado de %s ne eblas. Bv. vidi kun via administranto.",
    "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it." : "„%1$s“ ne estas instalita. Surmetado de %2$s ne eblas. Bv. vidi kun via administranto.",
    "External storage support" : "Subteno de ekstera konservejo",
    "Adds basic external storage support" : "Aldonas bazan subtenon por ekstera konservejo",
    "This application enables administrators to configure connections to external storage providers, such as FTP servers, S3 or SWIFT object stores, other Nextcloud servers, WebDAV servers, and more. Administrators can choose which types of storage to enable and can mount these storage locations for a user, a group, or the entire system. Users will see a new folder appear in their root Nextcloud directory, which they can access and use like any other Nextcloud folder. External storage also allows users to share files stored in these external locations. In these cases, the credentials for the owner of the file are used when the recipient requests the file from external storage, thereby ensuring that the recipient can access the shared file.\n\nExternal storage can be configured using the GUI or at the command line. This second option provides the advanced user with more flexibility for configuring bulk external storage mounts and setting mount priorities. More information is available in the external storage GUI documentation and the external storage Configuration File documentation." : "Tiu aplikaĵo ebligas al administranto agordi konektojn al eksteraj konservejoj, kiel FTP-serviloj, S3- aŭ SWIFT-objektkonservejoj, aliaj Nextcloud-serviloj, WebDAV-serviloj, kaj pli. Administranto ebligas certajn tipojn de konservejo kaj povas surmeti ilin por iu uzanto, iu grupo aŭ ĉiuj. Uzantoj vidos novan dosierujon, kiuj aperos en la radiko de ilia Nextcloud. Ekstera konservejo ankaŭ ebligas al uzantoj kunhavigi dosierojn konservitajn ene. Tiuokaze, akreditiloj de la dosierposedanto uziĝas, kiam la ricevanto petas la dosieron el la ekstera konservejo, por certigi, ke la ricevanto povas aliri la kunhavigitan dosieron.\n\nEkstera konservejo agordiĝas per grafika fasado aŭ komandlinie. Tiu lasta opcio estas pli fleksa por spertulo: amasa agordo de surmetingoj kaj de surmetingaj prioritatoj. Pli da informoj disponeblas en la dokumentaro pri ekstera konservejo.",
    "No external storage configured or you don't have the permission to configure them" : "Neniu ekstera konservejo agordita, aŭ vi ne rajtas agordi ĝin.",
    "Name" : "Nomo",
    "Storage type" : "Konserveja tipo",
    "Scope" : "Amplekso",
    "Open documentation" : "Malfermi la dokumentaron",
    "External storage enables you to mount external storage services and devices as secondary Nextcloud storage devices. You may also allow users to mount their own external storage services." : "Ekstera konservejo ebligas al vi surmeti servojn de ekstera konservejo kaj aparatojn, kiel kromajn konservejojn. Vi povas ankaŭ permesi al uzantoj surmeti ilian proprajn eksterajn konservejojn.",
    "Folder name" : "Dosierujnomo",
    "Authentication" : "Aŭtentigo",
    "Configuration" : "Agordo",
    "Available for" : "Disponebla por",
    "Click to recheck the configuration" : "Alklaku por rekontroli la agordon",
    "Add storage" : "Aldoni konservejon",
    "Advanced settings" : "Altanivela agordo",
    "Allow users to mount external storage" : "Permesi al uzantoj surmeti eksteran konservejon",
    "External storages" : "Eksteraj konservejoj",
    "(group)" : "(grupo)",
    "SMB / CIFS" : "SMB / CIFS",
    "SMB / CIFS using OC login" : "SMB / CIFS uzante OC-ensaluto",
    "Global credentials can be used to authenticate with multiple external storages that have the same credentials." : "Ĝeneralaj akreditiloj utilas, kiam pluraj eksteraj konservejoj kunuzas la samajn akreditilojn."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-32.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_external/l10n/eo.js <==
OC.L10N.register(
    "files_external",
    {
    "Storage with ID \"%d\" not found" : "Konservejo kun identigilo „%d“ ne trovita",
    "Invalid backend or authentication mechanism class" : "Nevalida interna tipo aŭ aŭtentiga klaso",
    "Invalid mount point" : "Nevalida surmetingo",
    "Objectstore forbidden" : "„Objectstore“ malpermesata",
    "Invalid storage backend \"%s\"" : "Nevalida konserveja interna servo „%s“",
    "Not permitted to use backend \"%s\"" : "Ne permesatas uzi internan servon „%s“",
    "Not permitted to use authentication mechanism \"%s\"" : "Ne permesatas uzi aŭtentigan metodon „%s“",
    "Unsatisfied backend parameters" : "Neplenumitaj internservaj parametroj",
    "Unsatisfied authentication mechanism parameters" : "Neplenumitaj aŭtentigmetodaj parametroj",
    "Insufficient data: %s" : "Nesufiĉaj datumoj: %s",
    "Access key" : "Alira ŝlosilo",
    "Secret key" : "Sekreta ŝlosilo",
    "Builtin" : "Interne instalita",
    "None" : "Nenio",
    "OpenStack v2" : "OpenStack v2",
    "Login" : "Ensaluti",
    "Password" : "Pasvorto",
    "Tenant name" : "Nomo de la loĝanto (angle „tenant“)",
    "Identity endpoint URL" : "Retadreso de identeca finpunkto (angle „Identity endpoint“)",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Domajno",
    "Rackspace" : "Rackspace",
    "API key" : "API-ŝlosilo",
    "Global credentials" : "Ĝeneralaj akreditiloj",
    "Log-in credentials, save in database" : "Ensalutaj akreditiloj, konservi en datumbazo",
    "Log-in credentials, save in session" : "Ensalutaj akreditiloj, konservi en seanco",
    "RSA public key" : "Publika RSA-ŝlosilo",
    "Public key" : "Publika ŝlosilo",
    "RSA private key" : "Privata RSA-ŝlosilo",
    "Private key" : "Privata ŝlosilo",
    "Kerberos ticket" : "Kerberos-bileto (angle „ticket“)",
    "Bucket" : "Ujo (angle „bucket“)",
    "Hostname" : "Gastigonomo",
    "Port" : "Pordo",
    "Region" : "Regiono",
    "Enable SSL" : "Ŝalti SSL-on",
    "Enable Path Style" : "Uzi vojan stilon („path style“ angle)",
    "Legacy (v2) authentication" : "Aŭtentigo per malnova v2",
    "WebDAV" : "WebDAV",
    "URL" : "Retadreso",
    "Remote subfolder" : "Fora subdosierujo",
    "Secure https://" : "Sekura https://",
    "FTP" : "FTP",
    "Host" : "Gastigo",
    "Secure ftps://" : "Sekura ftps://",
    "Local" : "Loka",
    "Location" : "Loko",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Radiko",
    "SFTP with secret key login" : "SFTP kun sekretoŝlosila ensaluto",
    "Share" : "Kunhavigi",
    "Show hidden files" : "Montri kaŝitajn dosierojn",
    "Timeout" : "Eltempiĝo",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Servonomo",
    "Request timeout (seconds)" : "Eltempiĝo (sekundoj)",
    "External storage" : "Ekstera konservejo",
    "External storage support" : "Subteno de ekstera konservejo",
    "Adds basic external storage support" : "Aldonas bazan subtenon por ekstera konservejo",
    "Add storage" : "Aldoni konservejon",
    "Folder name" : "Dosierujnomo",
    "Authentication" : "Aŭtentigo",
    "Cancel" : "Cancel",
    "Edit" : "Modifi",
    "Never" : "Neniam",
    "Once every direct access" : "Unufoje okaze de senpera aliro",
    "Always" : "Ĉiam",
    "Read only" : "Nurlega",
    "Enable previews" : "Ŝalti antaŭrigardojn",
    "Enable sharing" : "Ŝalti kunhavigadon",
    "Enable encryption" : "Ŝalti ĉifradon",
    "Compatibility with Mac NFD encoding (slow)" : "Kongrueco kun Makintoŝa „NFD“ signara kodoprezento (malrapide)",
    "External storages" : "Eksteraj konservejoj",
    "Actions" : "Agoj",
    "Delete" : "Forigi",
    "Saved" : "Konservita",
    "Error generating key pair" : "Eraro dum generado de ŝlosila paro",
    "Generate keys" : "Generi ŝlosilojn",
    "Confirm" : "Konfirmi",
    "Global credentials can be used to authenticate with multiple external storages that have the same credentials." : "Ĝeneralaj akreditiloj utilas, kiam pluraj eksteraj konservejoj kunuzas la samajn akreditilojn.",
    "Save" : "Konservi",
    "External mount error" : "Eraro de surmetingo ekstera",
    "Storage type" : "Konserveja tipo",
    "Unknown" : "Nekonata",
    "Scope" : "Amplekso",
    "Personal" : "Persona",
    "System" : "Sistemo",
    "Error" : "Eraro",
    "Grant access" : "Doni alirpermeson",
    "Error configuring OAuth1" : "Eraro dum agordo de OAuth1",
    "Please provide a valid app key and secret." : "Bv. doni validan aplikaĵan ŝlosilon kaj sekreton.",
    "Error configuring OAuth2" : "Eraro dum agordo de OAuth2",
    "%s" : "%s",
    "OAuth1" : "OAuth1",
    "App key" : "Aplikaĵa ŝlosilo",
    "App secret" : "Aplikaĵosekreto",
    "OAuth2" : "OAuth2",
    "Client ID" : "Klientidentigilo",
    "Client secret" : "Klientosekreto",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Subteno de cURL en PHP ne estas ebligita aŭ instalita. Surmetado de %s ne eblas. Bv. vidi kun via administranto.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Subteno de FTP en PHP ne estas ebligita aŭ instalita. Surmetado de %s ne eblas. Bv. vidi kun via administranto.",
    "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it." : "„%1$s“ ne estas instalita. Surmetado de %2$s ne eblas. Bv. vidi kun via administranto.",
    "(Group)" : "(grupo)",
    "Check for changes" : "Serĉi la modifojn",
    "Disconnect" : "Malkonekti",
    "Admin defined" : "Difinita de administranto",
    "Delete storage?" : "Ĉu forigi konservejon?",
    "Click to recheck the configuration" : "Alklaku por rekontroli la agordon",
    "Saving …" : "Konservado...",
    "No external storage configured or you don't have the permission to configure them" : "Neniu ekstera konservejo agordita, aŭ vi ne rajtas agordi ĝin.",
    "Open documentation" : "Malfermi la dokumentaron",
    "Configuration" : "Agordo",
    "Available for" : "Disponebla por",
    "Advanced settings" : "Altanivela agordo"
},
"nplurals=2; plural=(n != 1);");
